pub fn execute_numeric(
rule_def: &RuleDefinition,
context_json: &str,
) -> RuleEngineResult<f64>Expand description
Execute a rule definition and coerce the result to f64.
pub fn execute_numeric(
rule_def: &RuleDefinition,
context_json: &str,
) -> RuleEngineResult<f64>Execute a rule definition and coerce the result to f64.